# Al Bhed

Simple CLI and Library that translates ASCII into Al Bhed

Python:

```python
from albhed import albhed

albhed("Hello, World!")
'Rammu, Funmt!'
```

Shell:

```shell
albhed Hello, World!
Rammu, Funmt!
```
